pub struct GraphvizStyle { /* private fields */ }Expand description
Parameters for Graphviz rendering.
Global parameters
rankdir
Nodes
The following nodes can be rendered using GraphvizNodeStyle:
AigNode::FalseAigNode::InputAigNode::LatchAigNode::And- output (by default, invisible node just to get an arrow)
xorgate (for miter)orgate (for miter).
Edges
Edge styles are additive. All edges implement the edge_all style. To that can be added:
edge_latchif the edge is pointing at a latchedge_complementif the edge is complementededge_outputif the edge is directed to a final output (an output for an AIG, the output of the finalOR/XORgate for a miter depending on its structure).
Implementations
Sourceimpl GraphvizStyle
impl GraphvizStyle