pub struct Lit(/* private fields */);Expand description
A SAT literal.
Note that all AIG nodes do not correspond to a SAT literal.
For example, AigNode::False node do not map to any literal, but rather is omitted
as false boolean variables can be removed from a clause without changing the problem.
Clauses that contain a true boolean variable (ie a complemented edge to AigNode::False node)
are obviously true and don’t need to be emitted.
These cases are handled by the internal LitRes data structure.
Implementations